Contributing to NLTK
====================

The Natural Language Toolkit exists thanks to the efforts of dozens
of voluntary developers who have contributed functionality and
bugfixes since the project began in 2000 (`contributors <https://github.com/nltk/nltk/blob/develop/AUTHORS.md>`_).
Information for contributors:

* `contributing to NLTK <https://github.com/nltk/nltk/blob/develop/CONTRIBUTING.md>`_
* `desired enhancements <https://github.com/nltk/nltk/issues?labels=enhancement&page=1&state=open>`_
* `contribute a corpus <https://github.com/nltk/nltk/wiki/Adding-a-Corpus>`_
* `nltk-dev mailing list <https://groups.google.com/group/nltk-dev>`_
* `GitHub Project <https://github.com/nltk/nltk>`_
